# Superdesk Core library
[![Build Status](https://travis-ci.org/superdesk/superdesk-core.png?branch=master)](https://travis-ci.org/superdesk/superdesk-core)
Utilities for building Superdesk applications.

### Installation

For installation instructions, please refer to the README file at: [https://github.com/superdesk/superdesk/](https://github.com/superdesk/superdesk/ "")
